@@ -2,6 +2,8 @@
 #  Copyright © 2021 Ingram Micro Inc. All rights reserved.
 #
 
+import decimal
+import re
 from collections import defaultdict
 from datetime import datetime
 from uuid import uuid4
@@ -38,7 +40,6 @@ from django.utils.functional import cached_property
 
 from lark.exceptions import LarkError
 
-
 iterable_types = (list, tuple)
 
 
@@ -243,6 +244,12 @@ class RQLFilterClass:
         """
         filter_name, operator, str_value = data.filter_name, data.operator, data.str_value
         list_operator = data.list_operator
+        filter_basename, namespace = data.filter_basename, data.namespace
+
+        if namespace and filter_basename == RQL_SEARCH_PARAM:
+            raise RQLFilterLookupError(details={
+                'error': f'Filter "{filter_basename}" can be applied only on top level.',
+            })
 
         if filter_name == RQL_SEARCH_PARAM:
             return self._build_q_for_search(operator, str_value)
@@ -847,7 +854,7 @@ class RQLFilterClass:
 
             typed_value = cls._convert_value(django_field, str_value, use_repr=use_repr)
             return typed_value
-        except (ValueError, TypeError):
+        except (ValueError, TypeError, decimal.InvalidOperation):
             raise RQLFilterValueError(**cls._get_error_details(
                 filter_name, filter_lookup, str_value,
             ))
@@ -874,13 +881,27 @@ class RQLFilterClass:
         if val == RQL_ANY_SYMBOL:
             return any_symbol_regex
 
-        new_val = val
+        new_val = cls._escape_regex_special_symbols(val)
         new_val = new_val[1:] if val[0] == RQL_ANY_SYMBOL else '^{0}'.format(new_val)
         new_val = new_val[:-1] if val[-1] == RQL_ANY_SYMBOL else '{0}$'.format(new_val)
         return new_val.replace(RQL_ANY_SYMBOL, any_symbol_regex).replace(
             star_replacer, RQL_ANY_SYMBOL,
         )
 
+    @staticmethod
+    def _escape_regex_special_symbols(str_value):
+        """Returns escaped string
+
+        Current like/ilike protocol (* in any place) implementation requires to execute regex.
+        Input string could be a not valid (braces not balanced db error)
+        or misinterpreted (symbols range). Regex is not supported by RQL so we can safely
+        escape redundant special symbols.
+        """
+        return (
+            re.escape(str_value)
+            .replace(r'\{0}'.format(RQL_ANY_SYMBOL), RQL_ANY_SYMBOL)
+        )
+
     @classmethod
     def _convert_value(cls, django_field, str_value, use_repr=False):
         val = cls.remove_quotes(str_value)
@@ -890,7 +911,10 @@ class RQLFilterClass:
             return float(val)
 
         elif filter_type == FilterTypes.DECIMAL:
-            return round(float(val), django_field.decimal_places)
+            if '.' in val:
+                integer_part, fractional_part = val.split('.', 1)
+                val = integer_part + '.' + fractional_part[:django_field.decimal_places]
+            return decimal.Decimal(val)
 
         elif filter_type == FilterTypes.DATE:
             return cls._convert_date_value(val)
